@@ -2,6 +2,7 @@
 from yourtools import WeChat
 from yourtools import MySQL
 from yourtools import Hive
+from sshtunnel import SSHTunnelForwarder
 
 
 def test_wechat():
@@ -35,16 +36,24 @@ def test_mysql():
     #     'charset': 'utf8'
     # }
     dbconfg = {
-        'host': '118.25.192.114',
-        'port': 3308,
-        'username': 'root',
-        'password': 'Data@2022!',
-        'db': 'test',
+        'host': '10.201.2.28',
+        'port': 3366,
+        'username': 'dm_pro',
+        'password': '75smTTORG7KX74Ff',
+        'db': 'dm_mdm',
         'charset': 'utf8'
     }
-    mysql = MySQL(dbconfg)
+    server = SSHTunnelForwarder(
+        ('10.202.1.6', 45535),
+        ssh_username='zfang',
+        ssh_password='VoNayH4285',
+        remote_bind_address=('10.201.2.113', 3366),
+        local_bind_address=('127.0.0.1', 3366)
+    )
+    mysql = MySQL(dbconfg, ssh_tunnel=server)
     # result = mysql.execute("insert into users_cdc(name,birthday,ts) values('灭霸2','2022-11-01 16:00:00','2022-11-01 16:00:00') ")
-    result = mysql.query("select * from users_cdc")
+    result = mysql.query(
+        "select brand_code,hospital_picture from hospital_base t where hospital_picture is not null and trim(hospital_picture) !='' ")
     print(result)
 
 
@@ -57,7 +66,7 @@ def test_hive():
         'auth': 'NOSASL'
     }
     hive = Hive(hive_connection)
-    hive_sql="""
+    hive_sql = """
         select shr_staff_no
       from dwd.dwd_other_billing_power_list t
       join (-- 近1个月有医疗收入开单的医生
